package com.atguigu.config;

import com.atguigu.interceptor.LoginAuthInterceptor;
import com.atguigu.properties.InterceptorsProperties;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.config.annotation.CorsRegistry;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurationSupport;

@Component
@Slf4j
public class WebMvcConfiguration extends WebMvcConfigurationSupport {
    @Autowired
    private LoginAuthInterceptor loginAuthInterceptor;
    @Autowired
    private InterceptorsProperties interceptorsProperties;

    /**
     * * 解决跨域
     *
     * @param registry 跨域注册表
     */
    protected void addCorsMappings(CorsRegistry registry) {
        log.info("WebMvcConfiguration===>开始跨域注册表...");
        registry.addMapping("/**")// 添加路径规则
                .allowCredentials(true)// 是否允许在跨域的情况下传递Cookie
                .allowedOriginPatterns("*")// 允许请求来源的域规则
                .allowedMethods("*").allowedHeaders("*");// 允许所有的请求头
    }

    /**
     * 注册自定义拦截器
     *
     * @param registry InterceptorRegistry
     */
    protected void addInterceptors(InterceptorRegistry registry) {
        log.info("WebMvcConfiguration===>开始注册自定义拦截器...");
        // 需要拦截的
        registry.addInterceptor(loginAuthInterceptor).addPathPatterns("/admin/**")
                .excludePathPatterns(interceptorsProperties.getNoAuthUrls());
    }
}