package com.atguigu.spzx.manger.controller;

import com.atguigu.spzx.manger.service.BrandService;
import com.atguigu.spzx.model.entity.product.Brand;
import com.atguigu.spzx.model.vo.result.Result;
import com.github.pagehelper.PageInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "品牌管理")
@RestController
@RequestMapping(value = "/admin/product/brand")
public class BrandController {
    @Autowired
    private BrandService brandService;

    @Operation(summary = "品牌列表查询", description = "品牌列表查询")
    @GetMapping("{page}/{limit}")
    public Result<PageInfo<Brand>> findByPage(@PathVariable Integer page, @PathVariable Integer limit) {
        PageInfo<Brand> pageInfo = brandService.findByPage(page, limit);
        return Result.success(pageInfo);
    }

    @Operation(summary = "品牌添加", description = "品牌添加")
    @PostMapping("save")
    public Result<Brand> save(@RequestBody Brand brand) {
        brandService.save(brand);
        return Result.success();
    }

    @Operation(summary = "修改品牌", description = "修改品牌")
    @PutMapping("updateById")
    public Result<Brand> updateById(@RequestBody Brand brand) {
        brandService.updateById(brand);
        return Result.success();
    }

    @Operation(summary = "删除品牌", description = "删除品牌")
    @DeleteMapping("deleteById/{id}")
    public Result<Long> deleteById(@PathVariable Long id) {
        brandService.deleteById(id);
        return Result.success();
    }

    @Operation(summary = "品牌列表", description = "品牌列表接口")
    @GetMapping("findAll")
    public Result<List<Brand>> findAll() {
        List<Brand> list = brandService.findAll();
        return Result.success(list);
    }
}