package com.atguigu.spzx.manger.controller;

import com.atguigu.spzx.manger.service.SysRoleService;
import com.atguigu.spzx.model.dto.system.AssginRoleDto;
import com.atguigu.spzx.model.dto.system.SysRoleDto;
import com.atguigu.spzx.model.entity.system.SysRole;
import com.atguigu.spzx.model.vo.result.Result;
import com.atguigu.spzx.model.vo.system.AllRolesVo;
import com.github.pagehelper.PageInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Tag(name = "角色相关接口")
@RestController
@RequestMapping(value = "/admin/system/sysRole")
public class SysRoleController {
    @Autowired
    private SysRoleService sysRoleService;

    @Operation(summary = "查询角色分页", description = "查询角色信息返回分页")
    @PostMapping("findByPage/{pageNum}/{pageSize}")
    public Result<PageInfo<SysRole>> findByPage(@RequestBody SysRoleDto sysRoleDto,
                                                @PathVariable(value = "pageNum") Integer pageNum, @PathVariable(value = "pageSize") Integer pageSize) {
        PageInfo<SysRole> pageInfo = sysRoleService.findByPage(sysRoleDto, pageNum, pageSize);
        return Result.success(pageInfo);
    }

    @Operation(summary = "添加角色", description = "添加角色相关内容")
    @PostMapping(value = "saveSysRole")
    public Result<SysRole> saveSysRole(@RequestBody SysRole sysRole) {
        sysRoleService.saveSysRole(sysRole);
        return Result.success();
    }

    @Operation(summary = "修改角色", description = "修改角色相关信息")
    @PutMapping(value = "updateSysRole")
    public Result updateSysRole(@RequestBody SysRole sysRole) {
        sysRoleService.updateSysRole(sysRole);
        return Result.success();
    }

    @Operation(summary = "根据角色id删除角色", description = "根据角色id删除角色信息")
    @DeleteMapping(value = "deleteById/{roleId}")
    public Result deleteById(@PathVariable(value = "roleId") Long roleId) {
        sysRoleService.deleteById(roleId);
        return Result.success();
    }

    @Operation(summary = "查询所有角色", description = "查询所有角色信息")
    @GetMapping(value = "findAllRoles/{userId}")
    public Result<AllRolesVo> findAllRoles(@PathVariable(value = "userId") Long userId) {
        AllRolesVo allRolesList = sysRoleService.findAllRoles(userId);
        return Result.success(allRolesList);
    }

    @Operation(summary = "保存角色数据", description = "保存角色数据信息")
    @PostMapping("doAssign")
    public Result doAssign(@RequestBody AssginRoleDto assginRoleDto) {
        sysRoleService.doAssign(assginRoleDto);
        return Result.success();
    }
}