package com.atguigu.spzx.manger.service.impl;

import com.atguigu.constant.MessageConstant;
import com.atguigu.exception.BunnyException;
import com.atguigu.spzx.manger.mapper.CategoryBrandMapper;
import com.atguigu.spzx.manger.service.CategoryBrandService;
import com.atguigu.spzx.model.dto.product.CategoryBrandDto;
import com.atguigu.spzx.model.entity.product.Brand;
import com.atguigu.spzx.model.entity.product.CategoryBrand;
import com.atguigu.utils.StringEmptyUtil;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class CategoryBrandServiceImpl implements CategoryBrandService {
    @Autowired
    private CategoryBrandMapper categoryBrandMapper;
    @Autowired
    private StringEmptyUtil emptyUtil;

    /**
     * 分类品牌列表
     *
     * @param page  当前页
     * @param limit 每页限制
     * @param dto   搜索条件实体类
     * @return PageInfo<CategoryBrand>
     */
    @Override
    public PageInfo<CategoryBrand> findByPage(Integer page, Integer limit, CategoryBrandDto dto) {
        Page<Object> startPage = PageHelper.startPage(page, limit);
        List<CategoryBrand> categoryBrandList = categoryBrandMapper.findByPage(dto);

        // 关闭资源
        startPage.close();
        return new PageInfo<>(categoryBrandList);
    }

    /**
     * 添加功能
     *
     * @param categoryBrand 分类品牌实体类
     */
    @Override
    public void save(CategoryBrand categoryBrand) {
        if (categoryBrand == null) {
            throw new BunnyException(MessageConstant.SAVE_DTO_IS_NULL);
        }
        categoryBrandMapper.save(categoryBrand);
    }

    /**
     * 修改功能
     *
     * @param categoryBrand 分类品牌实体类
     */
    @Override
    public void updateById(CategoryBrand categoryBrand) {
        if (categoryBrand == null) {
            throw new BunnyException(MessageConstant.UPDATE_DTO_IS_NULL);
        }
        categoryBrandMapper.updateById(categoryBrand);
    }

    /**
     * 删除功能
     *
     * @param id 删除的ID
     */
    @Override
    public void deleteById(Long id) {
        emptyUtil.isEmpty(id, MessageConstant.DELETE_ID_IS_NOT_EMPTY);
        categoryBrandMapper.deleteById(id);
    }

    /**
     * 添加功能
     *
     * @param categoryId 查询ID
     * @return List<Brand>
     */
    @Override
    public List<Brand> findBrandByCategoryId(Long categoryId) {
        emptyUtil.isEmpty(categoryId, MessageConstant.FIND_ID_IS_NOT_EMPTY);
        return categoryBrandMapper.findBrandByCategoryId(categoryId);
    }
}
