package com.atguigu.spzx.manger.service.impl;

import com.atguigu.constant.MessageConstant;
import com.atguigu.exception.BunnyException;
import com.atguigu.spzx.manger.mapper.ProductSpecMapper;
import com.atguigu.spzx.manger.service.ProductSpecService;
import com.atguigu.spzx.model.entity.product.ProductSpec;
import com.atguigu.utils.StringEmptyUtil;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class ProductSpecServiceImpl implements ProductSpecService {
    @Autowired
    private ProductSpecMapper productSpecMapper;
    @Autowired
    private StringEmptyUtil emptyUtil;

    /**
     * 列表查询
     *
     * @param page  当前页
     * @param limit 每页限制
     * @return 分页结果
     */
    @Override
    public PageInfo<ProductSpec> findByPage(Integer page, Integer limit) {
        Page<Object> startPage = PageHelper.startPage(page, limit);
        List<ProductSpec> productSpecList = productSpecMapper.findByPage();

        startPage.close();
        return new PageInfo<>(productSpecList);
    }

    /**
     * 添加功能
     *
     * @param productSpec 商品规格实体类
     */
    @Override
    public void save(ProductSpec productSpec) {
        if (productSpec == null) {
            throw new BunnyException(MessageConstant.SAVE_DTO_IS_NULL);
        }

        productSpecMapper.save(productSpec);
    }

    /**
     * 修改功能
     *
     * @param productSpec 商品规格实体类
     */
    @Override
    public void updateById(ProductSpec productSpec) {
        if (productSpec == null) {
            throw new BunnyException(MessageConstant.UPDATE_DTO_IS_NULL);
        }

        productSpecMapper.updateById(productSpec);
    }

    /**
     * 删除功能
     *
     * @param id 要删除的ID
     */
    @Override
    public void deleteById(Long id) {
        emptyUtil.isEmpty(id, MessageConstant.UPDATE_ID_IS_NOT_EMPTY);
        productSpecMapper.deleteById(id);
    }

    /**
     * 加载商品规格数据
     *
     * @return 列表
     */
    @Override
    public List<ProductSpec> findAll() {
        return productSpecMapper.findAll();
    }
}
